pub enum Storage {
Xattr,
ResourceFork,
}Expand description
The location of the compressed data
Compressed data can be stored either in the decmpfs xattr or in the resource fork.
Variants
Xattr
The decmpfs header is followed by a single compressed block
ResourceFork
The compressed data is stored separately, in the resource fork